Package: Rcpi
Type: Package
Version: 1.48.0
Title: Molecular Informatics Toolkit for Compound-Protein Interaction
        in Drug Discovery
Authors@R: c(
    person("Nan", "Xiao", email = "me@nanx.me", role = c("aut", "cre"),
    comment = c(ORCID = "0000-0002-0250-5673")),
    person("Dong-Sheng", "Cao", role = "aut"),
    person("Qing-Song", "Xu", email = "qsxu@csu.edu.cn", role = c("aut"))
    )
Description: A molecular informatics toolkit with an integration of
    bioinformatics and chemoinformatics tools for drug discovery.
License: Artistic-2.0 | file LICENSE
URL: https://nanx.me/Rcpi/, https://github.com/nanxstats/Rcpi
BugReports: https://github.com/nanxstats/Rcpi/issues
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
Depends: R (>= 3.0.2)
Imports: Biostrings, GOSemSim, curl, doParallel, foreach, httr2,
        jsonlite, methods, rlang, stats, utils
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
biocViews: Software, DataImport, DataRepresentation, FeatureExtraction,
        Cheminformatics, BiomedicalInformatics, Proteomics, GO,
        SystemsBiology
Config/testthat/edition: 3
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/Rcpi
git_branch: RELEASE_3_23
git_last_commit: 7b08591
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:08:03 UTC; biocbuild
Author: Nan Xiao [aut, cre] (ORCID: <https://orcid.org/0000-0002-0250-5673>),
  Dong-Sheng Cao [aut],
  Qing-Song Xu [aut]
Maintainer: Nan Xiao <me@nanx.me>
