#' @keywords internal
"_PACKAGE"

#' @import foreach doParallel Biostrings GOSemSim
#' @importFrom methods as
#' @importFrom stats cmdscale dist factanal na.omit prcomp predict sd
#' @importFrom utils capture.output combn read.csv
NULL
