% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Rcpi-datalist.R
\docType{data}
\name{AAMOE2D}
\alias{AAMOE2D}
\title{2D Descriptors for 20 Amino Acids calculated by MOE 2011.10}
\value{
AAMOE2D data
}
\description{
2D Descriptors for 20 Amino Acids calculated by MOE 2011.10
}
\details{
This dataset includes the 2D descriptors of
the 20 amino acids calculated by MOE 2011.10
used for scales extraction in this package.
}
\examples{
data(AAMOE2D)

}
