% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Rcpi-datalist.R
\docType{data}
\name{AATopo}
\alias{AATopo}
\title{Topological Descriptors for 20 Amino Acids calculated by Dragon}
\value{
AATopo data
}
\description{
Topological Descriptors for 20 Amino Acids calculated by Dragon
}
\details{
This dataset includes the topological descriptors of
the 20 amino acids calculated by Dragon (version 5.4)
used for scales extraction in this package.
}
\examples{
data(AATopo)

}
