% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/412-extractProtQSO.R
\name{extractProtQSO}
\alias{extractProtQSO}
\title{Quasi-Sequence-Order (QSO) Descriptor}
\usage{
extractProtQSO(x, nlag = 30, w = 0.1)
}
\arguments{
\item{x}{A character vector, as the input protein sequence.}

\item{nlag}{The maximum lag, defualt is 30.}

\item{w}{The weighting factor, default is 0.1.}
}
\value{
A length \code{20 + 20 + (2 * nlag)} named vector
}
\description{
Quasi-Sequence-Order (QSO) Descriptor
}
\details{
This function calculates the Quasi-Sequence-Order (QSO) descriptor
(Dim: \code{20 + 20 + (2 * nlag)}, default is 100).
}
\examples{
x = readFASTA(system.file('protseq/P00750.fasta', package = 'Rcpi'))[[1]]
extractProtQSO(x)

}
\references{
Kuo-Chen Chou. Prediction of Protein Subcellar Locations by
Incorporating Quasi-Sequence-Order Effect.
\emph{Biochemical and Biophysical Research Communications},
2000, 278, 477-483.

Kuo-Chen Chou and Yu-Dong Cai. Prediction of Protein Sucellular Locations by
GO-FunD-PseAA Predictor.
\emph{Biochemical and Biophysical Research Communications},
2004, 320, 1236-1239.

Gisbert Schneider and Paul Wrede. The Rational Design of
Amino Acid Sequences by Artifical Neural Networks and Simulated
Molecular Evolution: Do Novo Design of an Idealized Leader Cleavge Site.
\emph{Biophys Journal}, 1994, 66, 335-344.
}
\seealso{
See \code{\link{extractProtSOCN}}
for sequence-order-coupling numbers.
}
